"use client";
import { Box, Button, Container, Grid2, Typography } from "@mui/material";
import ArrowDownwardIcon from "@mui/icons-material/ArrowDownward";
import { ChangeEvent, FormEvent, useState } from "react";
import InputField from "./components/InputField";

interface IFormData {
    decoded: string;
    encoded: string;
    password: string;
}

export default function Home() {
    const [formData, setFormData] = useState<IFormData>({
        encoded: "",
        decoded: "",
        password: "",
    });

    const submitFormHandler = (e: FormEvent<HTMLFormElement>) => {
        e.preventDefault();
    };

    const onInputChangeHandler = (e: ChangeEvent<HTMLInputElement>) => {
        const { name, value } = e.target;
        setFormData((prevData) => ({
            ...prevData,
            [name.toLowerCase()]: value,
        }));
    };

    return (
        <div className="App">
            <Container sx={{ marginTop: 2 }} maxWidth="lg">
                <Typography
                    variant="h3"
                    sx={{
                        fontSize: {
                            xs: "24px",
                            sm: "36px",
                        },
                    }}
                >
                    Cypher Coder/Decoder
                </Typography>
                <Box
                    sx={{
                        maxWidth: {
                            xs: "90%",
                            sm: "80%",
                            lg: "70%",
                        },
                    }}
                    component="form"
                    autoComplete="off"
                    onSubmit={submitFormHandler}
                    paddingY={2}
                >
                    <Grid2 container direction="column" spacing={2}>
                        <InputField name="Decoded" value={formData.decoded} onChange={onInputChangeHandler} />
                        <Grid2
                            container
                            alignItems="center"
                            sx={{
                                flexDirection: {
                                    xs: "column",
                                    md: "row",
                                },
                            }}
                        >
                            <Grid2 size={7}>
                                <InputField name="Password" value={formData.password} onChange={onInputChangeHandler} />
                            </Grid2>
                            <Grid2 container justifyContent={{}}>
                                <Grid2>
                                    <Button size="small" variant="contained" startIcon={<ArrowDownwardIcon />}>
                                        <Typography
                                            sx={{
                                                display: { xs: "none", md: "inline" },
                                            }}
                                        >
                                            Encode
                                        </Typography>
                                    </Button>
                                </Grid2>

                                <Grid2>
                                    <Button
                                        size="small"
                                        variant="contained"
                                        startIcon={<ArrowDownwardIcon sx={{ transform: "rotate(180deg)" }} />}
                                    >
                                        <Typography
                                            sx={{
                                                display: { xs: "none", md: "inline" },
                                            }}
                                        >
                                            Decode
                                        </Typography>
                                    </Button>
                                </Grid2>
                            </Grid2>
                        </Grid2>

                        <InputField name="Encoded" value={formData.encoded} onChange={onInputChangeHandler} />
                    </Grid2>
                </Box>
            </Container>
        </div>
    );
}
